@@ -4,6 +4,19 @@ class BoticordException(Exception):
     """
 
 
+class InternalException(BoticordException):
+    """Exception that's thrown when an local operation operation fails.
+
+    Attributes
+    ----------
+    response:
+        The meaning of the exception
+    """
+
+    def __init__(self, response):
+        super().__init__(response)
+
+
 class HTTPException(BoticordException):
     """Exception that's thrown when an HTTP request operation fails.
 
@@ -11,8 +24,6 @@ class HTTPException(BoticordException):
     ----------
     response:
         The response of the failed HTTP request.
-    message:
-        The text of the error. Could be an empty string.
     """
 
     def __init__(self, response):
